@@ -19,13 +19,13 @@
 #ifndef PLAYGROUNDDELEGATE_H
 #define PLAYGROUNDDELEGATE_H
 
-#include <QtWidgets/QAbstractItemDelegate>
+#include <QAbstractItemDelegate>
 #include <QAbstractItemView>
 
 class PlaygroundDelegate : public QAbstractItemDelegate
 {
   public:
-    PlaygroundDelegate(QObject *parent = 0);
+    explicit PlaygroundDelegate(QObject *parent = 0);
   private:
     virtual QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
     virtual void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
